
#include <iostream>
#include <string>
using namespace std;

#include "translator.h"
#include "gramparse.hpp"
#include "parse.hpp"

string translated;
IfsqlError ifsqlError;

static int  lookahead_token;	/* one-token lookahead */
static bool have_lookahead;	/* lookahead_token set? */


extern "C" {
const IfsqlError* translateIFSQL (const char** dest, const char* source)
{
	have_lookahead = false;

	ifsql_parser_init ();
	ifsql_scanner_init (source);
	int ifsql_yyresult = ifsql_yyparse();
	ifsql_scanner_finish();

	if (ifsql_yyresult)				/* error */
		return &ifsqlError;

	*dest = translated.c_str();
	return 0;
}
} // extern "C"


int ifsql_yylex(void)
{
	int			cur_token;

	/* Get next token --- we might already have it */
	if (have_lookahead)
	{
		cur_token = lookahead_token;
		have_lookahead = false;
	}
	else
		cur_token = base_ifsql_yylex();

	/* Do we need to look ahead for a possible multiword token? */
	switch (cur_token)
	{
		case UNION:
			/* UNION JOIN must be reduced to a single UNIONJOIN token */
			lookahead_token = base_ifsql_yylex();
			if (lookahead_token == JOIN)
				cur_token = UNIONJOIN;
			else
				have_lookahead = true;
			break;

		default:
			break;
	}

	return cur_token;
}
